@@ -32,16 +32,18 @@ module God
         begin
           uid_num = Etc.getpwnam(self.uid).uid if self.uid
           gid_num = Etc.getgrnam(self.gid).gid if self.gid
+          gid_num = Etc.getpwnam(self.uid).gid if self.gid.nil? && self.uid
 
           ::Dir.chroot(self.chroot) if self.chroot
-          ::Process.groups = [gid_num] if self.gid
-          ::Process::Sys.setgid(gid_num) if self.gid
+          ::Process.groups = [gid_num] if gid_num
+          ::Process.initgroups(self.uid, gid_num) if self.uid && gid_num
+          ::Process::Sys.setgid(gid_num) if gid_num
           ::Process::Sys.setuid(uid_num) if self.uid
         rescue ArgumentError, Errno::EPERM, Errno::ENOENT
           exit(1)
         end
 
-        File.writable?(file_in_chroot(file)) ? exit(0) : exit(1)
+        File.writable?(file_in_chroot(file)) ? exit!(0) : exit!(1)
       end
 
       wpid, status = ::Process.waitpid2(pid)
@@ -246,6 +248,7 @@ module God
               r.close
               pid = self.spawn(command)
               puts pid.to_s # send pid back to forker
+              exit!(0)
             end
 
             ::Process.waitpid(opid, 0)
@@ -295,11 +298,13 @@ module God
         File.umask self.umask if self.umask
         uid_num = Etc.getpwnam(self.uid).uid if self.uid
         gid_num = Etc.getgrnam(self.gid).gid if self.gid
+        gid_num = Etc.getpwnam(self.uid).gid if self.gid.nil? && self.uid
 
         ::Dir.chroot(self.chroot) if self.chroot
         ::Process.setsid
-        ::Process.groups = [gid_num] if self.gid
-        ::Process::Sys.setgid(gid_num) if self.gid
+        ::Process.groups = [gid_num] if gid_num
+        ::Process.initgroups(self.uid, gid_num) if self.uid && gid_num
+        ::Process::Sys.setgid(gid_num) if gid_num
         ::Process::Sys.setuid(uid_num) if self.uid
         self.dir ||= '/'
         Dir.chdir self.dir
